pub struct ImageInfo {
pub width: usize,
pub height: usize,
pub format: PixelFormat,
pub row_stride: usize,
}Expand description
Metadata returned after a successful image decode.
Fields
width: usizeWidth of the decoded image in pixels.
height: usizeHeight of the decoded image in pixels.
format: PixelFormatPixel format of the decoded data written to the tensor.
row_stride: usizeRow stride in bytes used when writing into the tensor.